@@ -1,7 +1,10 @@
-# $Id: Safari.pm,v 1.12 2007/01/10 04:14:10 comdog Exp $
+# $Id: Safari.pm 2379 2007-11-10 21:15:33Z comdog $
 package HTTP::Cookies::Safari;
 use strict;
 
+use warnings;
+no warnings;
+
 =head1 NAME
 
 HTTP::Cookies::Safari - Cookie storage and management for Safari
@@ -24,7 +27,6 @@ the unix 32-bit epoch, this file changes the expiry date to 0xFFFFFFFF
 in unix seconds. That should be enough for anyone, at least to the next
 release.
 
-
 See L<HTTP::Cookies>.
 
 =head1 SOURCE AVAILABILITY
@@ -74,7 +76,7 @@ use vars qw( $VERSION );
 use constant TRUE  => 'TRUE';
 use constant FALSE => 'FALSE';
 
-$VERSION = sprintf "%2d.%02d", q$Revision: 1.12 $ =~ m/ (\d+) \. (\d+) /xg;
+$VERSION = sprintf "%2d.%02d", qw( 1 13 );
 
 use Date::Calc;
 use Mac::PropertyList;
@@ -136,9 +138,12 @@ sub save
 	my $plist = Mac::PropertyList::array->new( [] );
 	print STDERR "plist is $plist\n";
 	
+	
     $self->scan(
     	do {
+    	
     	my $array = $plist->value;
+		my $n = 1;
 
     	sub {
 			my( $version, $key, $val, $path, $domain, $port,
